<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        title="业绩评定表"
        width="900px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules"  label-width="150" >
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="供方名称:" prop="name" >
              <el-input v-model="state.form.name"  placeholder="请输入供方名称" disabled/>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="地址:" prop="address" >
              <el-input v-model="state.form.address"  placeholder="请输入地址"  type="textarea" :rows="1" disabled/>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="8">
            <el-form-item label="联系人:" prop="person" >
              <el-input v-model="state.form.person"  placeholder="请输入联系人" disabled/>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="联系电话:" prop="phone" >
              <el-input v-model="state.form.phone" placeholder="请输入联系电话" disabled/>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="邮编:" prop="emil" >
              <el-input v-model="state.form.emil" placeholder="请输入邮编" :disabled="title === '查看'"/>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="8">
            <el-form-item label="供应产品:" prop="product" >
              <el-input v-model="state.form.product" placeholder="请输入供应产品" disabled/>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="产品类别:" prop="type" >
              <el-input v-model="state.form.type" placeholder="请输入产品类别" :disabled="title === '查看'"/>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="评审依据:" prop="gist" >
              <el-input v-model="state.form.gist" type="textarea" :rows="1"  placeholder="请输入评审依据" :disabled="title === '查看'"/>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="验证方式:" prop="verify" >
              <el-radio-group v-model="state.form.verify" :disabled="title === '查看'">
                <el-radio :label="1">现场验证</el-radio>
                <el-radio :label="2">入库验证</el-radio>
                <el-radio :label="3">供方资源处验证</el-radio>
              </el-radio-group>
            </el-form-item>
          </el-col>
        </el-row>
        <el-table :data="state.tableData" border :span-method="arraySpanMethod" style="margin-bottom: 15px">
          <el-table-column align="center" prop="content" fixed min-width="100"></el-table-column>
          <el-table-column align="center" prop="name" width="120"></el-table-column>
          <el-table-column align="center" label="优（86-100）" prop="" min-width="120">
            <template #default="scope">
              <el-input :disabled="title === '查看'"  v-model="scope.row.good"></el-input>
            </template>
          </el-table-column>
          <el-table-column align="center" label="良（71-85）" prop="" min-width="120">
            <template #default="scope">
              <el-input :disabled="title === '查看'" v-model="scope.row.fine"></el-input>
            </template>
          </el-table-column>
          <el-table-column align="center" label="中（60-70）" prop="" min-width="120">
            <template #default="scope">
              <el-input :disabled="title === '查看'" v-model="scope.row.middle"></el-input>
            </template>
          </el-table-column>
          <el-table-column align="center" label="差（＜60）" prop="" min-width="120">
            <template #default="scope">
              <el-input :disabled="title === '查看'" v-model="scope.row.bad"></el-input>
            </template>
          </el-table-column>
          <el-table-column align="center" prop="conclusion" label="结论" fixed="right" min-width="85"></el-table-column>
        </el-table>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="评审意见:" prop="opinion" >
              <el-radio-group v-model="state.form.opinion" :disabled="title === '查看'">
                <el-radio :label="1">保留(≥80)</el-radio>
                <el-radio :label="2">暂停，整改后再评价(≥65)</el-radio>
                <el-radio :label="3">剔除(＜65)</el-radio>
              </el-radio-group>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="参加评审人员签字:" prop="reviewUsers" >
              <el-select clearable
                 v-model="state.checkList"
                 multiple
                 collapse-tags
                 collapse-tags-tooltip
                 :disabled="title =='查看'"
                 filterable
                 style="width: 100%"
                 @change="changeCheckPeople"
              >
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="日期:" prop="reviewTime" >
              <el-date-picker
                  :disabled="title === '查看'"
                  v-model="state.form.reviewTime"
                  type="date"
                  placeholder="请选择日期"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="审批意见:" prop="reviewMess" >
              <el-input type="textarea" :rows="2" v-model="state.form.reviewMess"  placeholder="请输入审批意见" :disabled="title === '查看'" style="width: 100%"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="审批人:" prop="checkId" >
              <el-select clearable v-model="state.form.checkId" :disabled="title =='查看'" filterable  style="width: 100%">
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="日期:" prop="checkTime" >
              <el-date-picker
                  :disabled="title === '查看'"
                  v-model="state.form.checkTime"
                  type="date"
                  placeholder="请选择日期"
              />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>

      <template #footer v-if="title !== '查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"   @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {computed, onMounted, reactive, ref, toRefs} from 'vue'
import Editor from "@/components/Editor/index.vue";
import {ElMessage} from "element-plus";
import {addNotice} from "@/api/backManage/notice";
import {addDict, editDict, getDictDetail} from "@/api/backManage/evaluate";
import {addCompany, checkName, distributeCompany, editCompany, getCompany} from "@/api/onlineEducation/company";
import {validEmail, verifyPhone} from "@/utils/validate";
import {addBasic, editBasic} from "@/api/companyInfo/basicInfo";
import Cookies from "js-cookie";
import {addSupplier, editPerformance, editSupplier, getPerformance} from "@/api/supplier/supplierList";
import {getUser} from "@/api/onlineEducation/user";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const validatePhone = (rule, value, callback)=>{
  if(value === ''){
    callback(new Error('请输入手机号'))
  }else{
    if(!verifyPhone(value)){
      callback(new Error('手机号格式有误'))
    }else{
      callback()
    }
  }
}


const state = reactive({
  form: {
    id: '',
    companyId: null,
    address: '',
    checkId: '',
    checkTime: '',
    gist: '',
    phone: '',
    emil: '',
    name: '',
    p1: '',
    p2: '',
    p3: '',
    p4: '',
    p5: '',
    p6: '',
    people: '',
    product: '',
    reviewMess: '',
    reviewTime: '',
    reviewUsers: '',
    type: '',
    verify: '',
  },
  formRules:{
    companyId: [{ required: true, message: '请选择企业', trigger: 'blur' }],
    address: [{ required: true, message: '请输入地址', trigger: 'blur' }],
    gist:[{ required: true, message: '请输入评审依据', trigger: 'blur' }],
    phone: [{ required: true, validator: validatePhone, trigger: 'blur' }],
    people: [{ required: true, message: '请输入联系人', trigger: 'blur' }],
    emil: [{ required: true, message: '请输入邮编', trigger: 'blur' }],
    product: [{ required: true, message: '请输入供应产品', trigger: 'blur' }],
    reviewMess: [{ required: true, message: '请选择审批意见', trigger: 'blur' }],
    reviewTime: [{ required: true, message: '请输入评审日期', trigger: 'blur' }],
    type: [{ required: true, message: '请输入产品类型', trigger: 'blur' }],
    verify: [{ required: true, message: '请选择验证方式', trigger: 'blur' }],
    name: [{ required: true, message: '请输入供方名称', trigger: 'blur' }],
    checkId: [{ required: true, message: '请选择审批人', trigger: 'blur' }],
    checkTime: [{ required: true, message: '请选择审批日期', trigger: 'blur' }],
    opinion: [{ required: true, message: '请选择评审意见', trigger: 'blur' }],
    reviewUsers: [{ required: true, message: '请选择评审人员', trigger: 'blur' }],
  },
  isAdmin: false,
  companyList: [],
  peopleList: [],
  supplierSureId: null,
  tableData: [
    {
      content: '评审内容（P）',
      name: '产品质量 p1',
      conclusion: 'Σ(Pi)/6 ='
    },
    {
      name: '交货期 p2'
    },
    {

      name: '履约能力 p3'
    },
    {

      name: '价格 p4'
    },
    {

      name: '售后服务 p5'
    },
    {
      name: '资历 p6'
    },
  ],
  checkList: []

})

onMounted(() => {

})
const openDialog = async (type, value) => {
  title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看' ;
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  state.isAdmin = userInfo.userType === 0;
  state.form.companyId = value.companyId
  state.supplierSureId = value.id
  await getPerformanceInfo()
  state.form.name = value.supplierName
  state.form.address = value.supplierAddr
  state.form.product = value.merito
  state.form.person = value.user
  state.form.phone = value.phone
  await  getPeopleList()

  dialogVisible.value = true;
}
const demo = ref([
  {
    rage: '86-100',
    field: 'good'
  },
  {
    rage: '71-85',
    field: 'fine'
  },
  {
    rage: '60-70',
    field: 'middle'
  },
  {
    rage: '0-59',
    field: 'bad'
  },
])
const getPerformanceInfo = async () => {
  const param = {
    supplierSureId: state.supplierSureId
  }
  const res = await getPerformance(param)
  if(res.code == 200){
    state.form.id = res.data.id
    if(!res.data.p1){
      return
    }
    state.form = res.data
    state.form.checkId = res.data.checkId ==0? null: res.data.checkId
    state.checkList = res.data.reviewUsers ? res.data.reviewUsers.split(',').map(i => Number(i)):[]
    //更新表格字段名
    const p1Field = getMatchedField(res.data.p1)
    if(p1Field){
      state.tableData[0][p1Field] = res.data.p1
    }
    const p2Field = getMatchedField(res.data.p2)
    if(p2Field){
      state.tableData[1][p2Field] = res.data.p2
    }
    const p3Field = getMatchedField(res.data.p3)
    if(p3Field){
      state.tableData[2][p3Field] = res.data.p3
    }
    const p4Field = getMatchedField(res.data.p4)
    if(p4Field){
      state.tableData[3][p4Field] = res.data.p4
    }
    const p5Field = getMatchedField(res.data.p5)
    if(p5Field){
      state.tableData[4][p5Field] = res.data.p5
    }
    const p6Field = getMatchedField(res.data.p6)
    if(p6Field){
      state.tableData[5][p6Field] = res.data.p6
    }
    const sum = res.data.p1+res.data.p2+res.data.p3+res.data.p4+res.data.p5+res.data.p6
    state.tableData[0].conclusion += (sum/6).toFixed(2)


  }else{
    ElMessage.warning(res.message)
  }
}
const getMatchedField = (num) => {
  for (const item of demo.value) {
    const [min, max] = item.rage.split('-').map(Number);
    if (num >= min && num <= max) {
      return item.field; // 返回匹配的字段名（如 "good"）
    }
  }
  return null; // 无匹配时返回 null
}

const onSubmit = async () => {
  state.tableData[0].conclusion = 'Σ(Pi)/6 ='
  if(!handleTableData()){
    return
  }
  const valid = await busRef.value.validate();
  if(valid){
     if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
       data.reviewUsers = state.checkList.join(',')
      const res = await editPerformance(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }
  }
}

const handleTableData = () => {
  console.log('dd',state.form)
  const demo = ['good','fine','middle','bad']
  let sum = 0
  state.tableData[0].conclusion = 'Σ(Pi)/6 ='
  for(const item of  state.tableData){
    //填了两个及以上或没填
    const length = Object.keys(item).filter(key => (demo.includes(key) && item[key] !== '')).length
    if(length>1 || length===0){
      ElMessage.warning(`请填写${item.name}的正确评分`)
      return false;
    }
    //填的数字不在范围内
    const content = Object.keys(item).filter(key => (demo.includes(key) && item[key] !== ''))
    if(content == 'good'){
      if(!(item[content]>=86 &&item[content]<=100)){
        ElMessage.warning(`请填写${item.name}的正确评分`)
        return false
      }else{
        sum+=Number(item[content])
      }
    }else if(content == 'fine'){
      if(!(item[content]>=71 &&item[content]<=85)){
        ElMessage.warning(`请填写${item.name}的正确评分`)
        return false
      }else{
        sum+=Number(item[content])
      }
    }else if(content == 'middle'){
      if(!(item[content]>=60 &&item[content]<=70)){
        ElMessage.warning(`请填写${item.name}的正确评分`)
        return false
      }else{
        sum+=Number(item[content])
      }
    }else if(content == 'bad'){
      if(!(item[content]<60)){
        ElMessage.warning(`请填写${item.name}的正确评分`)
        return false
      }else{
        sum+=Number(item[content])
      }
    }
    item.num = Number(item[content])
  }
  state.form.p1 = state.tableData[0].num
  state.form.p2 = state.tableData[1].num
  state.form.p3 = state.tableData[2].num
  state.form.p4 = state.tableData[3].num
  state.form.p5 = state.tableData[4].num
  state.form.p6 = state.tableData[5].num
  state.tableData[0].conclusion += (sum/6).toFixed(2)
  return true
}
const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")

}
const reset = () => {
  state.form = {
    id: '',
    companyId: null,
    address: '',
    checkId: '',
    checkTime: '',
    gist: '',
    phone: '',
    emil: '',
    name: '',
    p1: '',
    p2: '',
    p3: '',
    p4: '',
    p5: '',
    p6: '',
    people: '',
    product: '',
    reviewMess: '',
    reviewTime: '',
    reviewUsers: '',
    type: '',
    verify: '',
  }
  state.companyList = []
  state.checkList = []
  state.tableData = [
    {
      content: '评审内容（P）',
      name: '产品质量 p1',
      conclusion: 'Σ(Pi)/6 ='
    },
    {
      name: '交货期 p2'
    },
    {

      name: '履约能力 p3'
    },
    {

      name: '价格 p4'
    },
    {

      name: '售后服务 p5'
    },
    {

      name: '资历 p6'
    },
  ]
}
const arraySpanMethod = ( {row, column, rowIndex, columnIndex}) => {
  if(columnIndex == 0 || columnIndex == 6){
    if (rowIndex === 0) {
      return {
        rowspan: 7,
        colspan: 1
      }
    } else {
      // 其他行不显示（被合并）
      return {
        rowspan: 0,
        colspan: 0
      }
    }
  }

}
const getPeopleList = async ()=> {
  const queryParams = {
    pageNum: 1,
    pageSize: 9999,
    companyId: state.form.companyId
  }
  const res = await getUser(queryParams)
  if(res.code == 200){
    state.peopleList = res.data.list?res.data.list:[]
  }else{
    ElMessage.warning(res.message)
  }
};
const changeCheckPeople = (val) => {
  state.form.reviewUsers = state.checkList.join(',')
}

defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
